@@ -33,7 +33,7 @@
 #include <QApplication>
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kmessagebox.h>
 #include <QMenu>
 
